const fs = require('fs')
const yaml = require('yaml')

const directoryPath = './pis/'

function sortAndMergeYAMLFiles() {
    try {
        const files = fs.readdirSync(directoryPath);

        let mergedData = [];

        files.forEach(file => {
            const data = fs.readFileSync(directoryPath + file, 'utf-8');

            const parsedData = yaml.parse(data)

            if (parsedData && typeof parsedData === 'object' && parsedData.pis) {
                mergedData.push(...parsedData.pis)
            } else {
                if (Array.isArray(parsedData)) {
                    mergedData.push(...parsedData);
                } else {
                    console.error("Incorrect YAML")
                }
            }
        });

        mergedData.sort((a, b) => {
            const codeA = parseInt(a.code);
            const codeB = parseInt(b.code);
            return codeA - codeB
        })

        

        // Construct the output string, removing duplicates
        let outputString = "pis:\n";
        const seenCodes = new Set();
        mergedData.forEach(item => {
            if (!seenCodes.has(item.code) && item.stops.length > 0) {
                seenCodes.add(item.code);
                outputString += `  - code: "${item.code}"\n`;
                outputString += `    stops: [${item.stops.map(stop => `${stop}`).join(',')}]\n`;
                outputString += `    toc: "${item.toc || "gw"}"\n`;
            }
        });

        try {
            fs.writeFileSync('./pis/gw.yaml', outputString);
            console.log("Overwritten gw.pis")
        } catch (err) {
            console.error("Error writing gw.pis", err)
        }

        // Remove any files created by dgp2
        files.forEach(file => {
            if (file.startsWith('auto-')) {
                fs.unlinkSync(directoryPath + file);
                console.log(`Deleted file: ${file}`);
            }
        });

    } catch(err) {
        console.error('Error merging YAML:', err)
    }
}


sortAndMergeYAMLFiles();